Index: src/vm/ffi_posix.cc |
diff --git a/src/vm/ffi_posix.cc b/src/vm/ffi_posix.cc |
index e09a2830800ec16f007ac22cab29d5a3f646b801..b212049a03323a6e216fc79e634f6aca26aaf5b7 100644 |
--- a/src/vm/ffi_posix.cc |
+++ b/src/vm/ffi_posix.cc |
@@ -2,9 +2,9 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-#if defined(FLETCH_TARGET_OS_POSIX) |
+#if defined(DARTINO_TARGET_OS_POSIX) |
-#ifdef FLETCH_ENABLE_FFI |
+#ifdef DARTINO_ENABLE_FFI |
#include "src/vm/ffi.h" |
@@ -20,7 +20,7 @@ |
#include "src/vm/object.h" |
#include "src/vm/process.h" |
-namespace fletch { |
+namespace dartino { |
char* ForeignUtils::DirectoryName(char* path, char* buffer, size_t len) { |
strncpy(buffer, path, len); |
@@ -70,7 +70,7 @@ bool ForeignFunctionInterface::AddDefaultSharedLibrary(const char* library) { |
ScopedLock lock(mutex_); |
void* handle = dlopen(library, RTLD_LOCAL | RTLD_LAZY); |
if (handle != NULL) { |
// We have to maintain the insertion order (see fletch_api.h). |
if (libraries_ == NULL) { |
libraries_ = new DefaultLibraryEntry(handle, libraries_); |
} else { |
@@ -159,8 +159,8 @@ END_NATIVE() |
BEGIN_NATIVE(ForeignErrno) { return Smi::FromWord(errno); } |
END_NATIVE() |
-} // namespace fletch |
+} // namespace dartino |
-#endif // FLETCH_ENABLE_FFI |
+#endif // DARTINO_ENABLE_FFI |
-#endif // defined(FLETCH_TARGET_OS_POSIX) |
+#endif // defined(DARTINO_TARGET_OS_POSIX) |
@@ -70,7 +70,7 @@ bool ForeignFunctionInterface::AddDefaultSharedLibrary(const char* library) { |
void* handle = dlopen(library, RTLD_LOCAL | RTLD_LAZY); |
if (handle != NULL) { |
- // We have to maintain the insertion order (see fletch_api.h). |
+ // We have to maintain the insertion order (see dartino_api.h). |
if (libraries_ == NULL) { |
libraries_ = new DefaultLibraryEntry(handle, libraries_); |